==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/fil-PH/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Ang mga asset na nakatalaga sa :name',
    'bulk_update_warn'	=> 'Ikaw ay mag-edit ng mga katangian ng :user_count mga gumagamit. Mangyaring tandaan na hindi mo maaaring mabago ang iyong sariling user attributes gamit ang form na ito, at kinakailangang magsagawa ng pag-edit sa iyong sariling user nang mag-isa.',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang gumagamit ng isang beses. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago.',
    'current_assets'    => 'Ang assets ay kasalukuyang nai-check out sa gumagamit na ito',
    'clone'             => 'I-clone ang User',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'I-edit ang Gumamit',
    'filetype_info'     => 'Ang mga pinapayagang uri ng file ay png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, at rar.',
    'history_user'      => 'Ang kasaysayan para sa :name',
    'info'				=> 'Impormasyon',
    'restore_user'		=> 'I-klik dito upang maibalik ang mga ito.',
    'last_login'        => 'Ang Huling Pag-login',
    'ldap_config_text'  => 'Pwedeng makita ang configuration settings ng LDAP Admin > Settings. Ang (opsyonal) napiling lokasyon ay itatakda para sa lahat ng mga na-import na mga gumagamit o user.',
    'print_assigned'    => 'I-print ang Lahat ng Nakatalaga',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Ang Software ay Nai-check out sa :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tingnan ang User :name',
    'usercsv'           => 'Ang CSV file',
    'two_factor_admin_optin_help' => 'Ang iyong kasalukuyang mga admin settings ay napapahintulot ng selektibong pagpapatupad ng two-factor authentication.  ',
    'two_factor_enrolled' => 'Ang Na-enroll na 2FA Device ',
    'two_factor_active'   => 'Ang 2FA Active ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/fil-PH/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Ang mga asset na nakatalaga sa :name',
    'bulk_update_warn'	=> 'Ikaw ay mag-edit ng mga katangian ng :user_count mga gumagamit. Mangyaring tandaan na hindi mo maaaring mabago ang iyong sariling user attributes gamit ang form na ito, at kinakailangang magsagawa ng pag-edit sa iyong sariling user nang mag-isa.',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang gumagamit ng isang beses. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago.',
    'current_assets'    => 'Ang assets ay kasalukuyang nai-check out sa gumagamit na ito',
    'clone'             => 'I-clone ang User',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'I-edit ang Gumamit',
    'filetype_info'     => 'Ang mga pinapayagang uri ng file ay png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, at rar.',
    'history_user'      => 'Ang kasaysayan para sa :name',
    'info'				=> 'Impormasyon',
    'restore_user'		=> 'I-klik dito upang maibalik ang mga ito.',
    'last_login'        => 'Ang Huling Pag-login',
    'ldap_config_text'  => 'Pwedeng makita ang configuration settings ng LDAP Admin > Settings. Ang (opsyonal) napiling lokasyon ay itatakda para sa lahat ng mga na-import na mga gumagamit o user.',
    'print_assigned'    => 'I-print ang Lahat ng Nakatalaga',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Ang Software ay Nai-check out sa :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tingnan ang User :name',
    'usercsv'           => 'Ang CSV file',
    'two_factor_admin_optin_help' => 'Ang iyong kasalukuyang mga admin settings ay napapahintulot ng selektibong pagpapatupad ng two-factor authentication.  ',
    'two_factor_enrolled' => 'Ang Na-enroll na 2FA Device ',
    'two_factor_active'   => 'Ang 2FA Active ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
